@@ -2,19 +2,29 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "Notas",
-    "New note" : "Nota nueva",
-    "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin salvar. ¡Al salir de la página perderá todos los cambios!",
-    "_%n word_::_%n words_" : ["%n palabra","%n palabras"],
     "The last viewed note cannot be accessed. " : "No se puede acceder a la última nota consultada. ",
-    "File error" : "Error de archivo",
+    "New note" : "Nota nueva",
     "Encryption Error" : "Error de encripción",
     "Error" : "Error",
-    "No notes found" : "No se encontraron notas",
+    "Settings" : "Configuraciones ",
+    "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin salvar. ¡Al salir de la página perderá todos los cambios!",
+    "All notes" : "Todas las notas",
+    "Categories" : "Categorías",
+    "Today" : "Hoy",
+    "Yesterday" : "Ayer",
+    "This week" : "Esta semana",
+    "This month" : "Este mes",
     "Delete note" : "Borrar nota",
-    "Favorite" : "Favorito",
-    "The note has unsaved changes." : "La nota contiene cambios sin guardar",
-    "Click here to try again" : "Haz click aquí para intentarlo de nuevo",
+    "Remove from favorites" : "Eliminar de favoritos",
+    "Add to favorites" : "Agregar a tus favoritos",
+    "Details" : "Detalles",
+    "Preview" : "Previsualizar",
+    "Edit" : "Editar",
+    "Category" : "Categoría",
+    "Uncategorized" : "Sin categoría",
     "Saving failed!" : "¡Falla al guardar!",
-    "Note saved" : "Nota guardada"
+    "_%n word_::_%n words_" : ["%n palabra","%n palabras"],
+    "Android app" : "Aplicación Android",
+    "iOS app" : "Aplicación iOS"
 },
 "nplurals=2; plural=(n != 1);");
